@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2012 by Peter Penz <peter.penz19@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2012 Peter Penz <peter.penz19@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kitemlistheader.h"
 #include "kitemlistview.h"
@@ -58,7 +45,8 @@ qreal KItemListHeader::columnWidth(const QByteArray& role) const
 void KItemListHeader::setColumnWidths(const QHash<QByteArray, qreal>& columnWidths)
 {
     if (!m_headerWidget->automaticColumnResizing()) {
-        foreach (const QByteArray& role, m_view->visibleRoles()) {
+        const auto visibleRoles = m_view->visibleRoles();
+        for (const QByteArray& role : visibleRoles) {
             const qreal width = columnWidths.value(role);
             m_headerWidget->setColumnWidth(role, width);
         }
