@@ -54,6 +54,12 @@ DolphinFacetsWidget::DolphinFacetsWidget(QWidget* parent) :
     m_ratingSelector->addItem(QIcon::fromTheme(QStringLiteral("starred-symbolic")), i18nc("@item:inlistbox", "Highest Rating"), 5);
     initComboBox(m_ratingSelector);
 
+    m_clearTagsAction = new QAction(QIcon::fromTheme(QStringLiteral("edit-clear-all")), i18nc("@action:inmenu", "Clear Selection"), this);
+    connect(m_clearTagsAction, &QAction::triggered, this, [this]() {
+        resetSearchTags();
+        Q_EMIT facetChanged();
+    });
+
     m_tagsSelector = new QToolButton(this);
     m_tagsSelector->setIcon(QIcon::fromTheme(QStringLiteral("tag")));
     m_tagsSelector->setMenu(new QMenu(this));
@@ -98,9 +104,7 @@ void DolphinFacetsWidget::resetSearchTerms()
     m_dateSelector->setCurrentIndex(0);
     m_ratingSelector->setCurrentIndex(0);
 
-    m_searchTags = QStringList();
-    updateTagsSelector();
-    updateTagsMenu();
+    resetSearchTags();
 }
 
 QStringList DolphinFacetsWidget::searchTerms() const
@@ -219,6 +223,13 @@ void DolphinFacetsWidget::removeSearchTag(const QString& tag)
     updateTagsSelector();
 }
 
+void DolphinFacetsWidget::resetSearchTags()
+{
+    m_searchTags = QStringList();
+    updateTagsSelector();
+    updateTagsMenu();
+}
+
 void DolphinFacetsWidget::initComboBox(QComboBox* combo)
 {
     combo->setFrame(false);
@@ -241,6 +252,7 @@ void DolphinFacetsWidget::updateTagsSelector()
     }
 
     m_tagsSelector->setEnabled(isEnabled() && (hasListedTags || hasSelectedTags));
+    m_clearTagsAction->setEnabled(hasSelectedTags);
 }
 
 void DolphinFacetsWidget::updateTagsMenu()
@@ -253,7 +265,8 @@ void DolphinFacetsWidget::updateTagsMenu()
 
 void DolphinFacetsWidget::updateTagsMenuItems(const QUrl&, const KFileItemList& items)
 {
-    m_tagsSelector->menu()->clear();
+    QMenu *tagsMenu = m_tagsSelector->menu();
+    tagsMenu->clear();
 
     QStringList allTags = QStringList(m_searchTags);
     for (const KFileItem &item: items) {
@@ -265,7 +278,7 @@ void DolphinFacetsWidget::updateTagsMenuItems(const QUrl&, const KFileItemList&
     const bool onlyOneTag = allTags.count() == 1;
 
     for (const QString& tagName : qAsConst(allTags)) {
-        QAction* action = m_tagsSelector->menu()->addAction(QIcon::fromTheme(QStringLiteral("tag")), tagName);
+        QAction *action = tagsMenu->addAction(QIcon::fromTheme(QStringLiteral("tag")), tagName);
         action->setCheckable(true);
         action->setChecked(m_searchTags.contains(tagName));
 
@@ -283,5 +296,10 @@ void DolphinFacetsWidget::updateTagsMenuItems(const QUrl&, const KFileItemList&
         });
     }
 
+    if (allTags.count() > 1) {
+        tagsMenu->addSeparator();
+        tagsMenu->addAction(m_clearTagsAction);
+    }
+
     updateTagsSelector();
 }
