@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Peter Penz <peter.penz19@gmail.com>             *
- *   Copyright (C) 2008 by Fredrik Höglund <fredrik@kde.org>               *
- *   Copyright (C) 2012 by Mark Gaiser <markg85@gmail.com>                 *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2010 Peter Penz <peter.penz19@gmail.com>
+ * SPDX-FileCopyrightText: 2008 Fredrik Höglund <fredrik@kde.org>
+ * SPDX-FileCopyrightText: 2012 Mark Gaiser <markg85@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "dolphinfilemetadatawidget.h"
 
@@ -94,9 +81,16 @@ void DolphinFileMetaDataWidget::setPreview(const QPixmap& pixmap)
 
 QPixmap DolphinFileMetaDataWidget::preview() const
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     if (m_preview->pixmap()) {
         return *m_preview->pixmap();
     }
+#else
+    if (!m_preview->pixmap(Qt::ReturnByValue).isNull()) {
+        return m_preview->pixmap(Qt::ReturnByValue);
+    }
+#endif
+
     return QPixmap();
 }
 
